/**
 * Copyright (C) 2018 - 2019 Oleksandr Tyshkovets <olexandr.tyshkovets@gmail.com>
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.github.aint.octopus

import spock.lang.Specification
import spock.lang.Subject

import static org.assertj.core.api.Assertions.assertThat

class IntegrationsActuatorEndpointTest extends Specification {

    private OctopusService octopusService = Stub(OctopusService)

    @Subject
    IntegrationsActuatorEndpoint actuatorEndpoint = new IntegrationsActuatorEndpoint(octopusService)

    def "integrations"() {
        def json = DependencyJson.builder()
                .eventType(DependencyJson.EventType.CREATE)
                .serviceMetadata("Java, Spring")
                .serviceName("App")
                .build()
        given:
        octopusService.createEvent() >> json

        when:
        def actualJson = actuatorEndpoint.integrations()

        then:
        assertThat(actualJson).isEqualTo(json)
    }
}
